/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __AIR_MEDIAHUB_PROGRESSBAR_H__
#define __AIR_MEDIAHUB_PROGRESSBAR_H__

struct progressbar;

struct progressbar_ops {
	int (*get_value)(void *data);
	int (*set_value)(void *data);
};

enum progressbar_time_format {
	PROG_TIME_FORMAT_FIT,	/* eg) 7:17 - default */
	PROG_TIME_FORMAT_FULL,	/* eg) 00:07:17 */
};

struct progressbar *progressbar_create(Evas_Object *base, const char *style);
void progressbar_destroy(struct progressbar *m);

void progressbar_set_parts(struct progressbar *m, const char *slider,
		const char *total, const char *progress, const char *separator);
void progressbar_set_ops(struct progressbar *m,
		struct progressbar_ops *ops, void *data);
void progressbar_set_time_format(struct progressbar *m,
		enum progressbar_time_format fmt);
void progressbar_reset(struct progressbar *m, int position, int duration);

void progressbar_show(struct progressbar *m);
void progressbar_hide(struct progressbar *m);

void progressbar_start(struct progressbar *m);
void progressbar_stop(struct progressbar *m);
void progressbar_pause(struct progressbar *m);
void progressbar_resume(struct progressbar *m);

#endif
